/* **************************************************************************
 * This file is part of Timothy_benchmark
 *
 * Copyright (c) 2014/15 Maciej Cytowski
 * Copyright (c) 2014/15 ICM, University of Warsaw, Poland
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * *************************************************************************/

#ifdef __MIC__
#define MIC_ATTR __attribute__((target(mic)))
#else
#define MIC_ATTR
#endif

typedef struct cell_data_t {
  int lifetime;         /* age of the cell */
  int phase;            /* actual phase of the cell (0=G0,1=G1,2=S,3=G2,4=M,5=Necrotic) */
  int age;              /* cell's age */
  int death;            /* 1 - dead cell, 0 - living cell */
  int halo;             /* cell on the border of parallel region */
  float phasetime;      /* actual phase time */
  float g1;             /* g1 phase lenght - randomly selected for each new cell */
  float s;              /* s phase lenght - randomly selected for each new cell */
  float g2;             /* g2 phase lenght - randomly selected for each new cell */
  float m;              /* m phase lenght - randomly selected for each new cell */
  float young;          /* Young modulus - randomly selected for each new cell */
  long long gid;   	/* global ID of the particle */
  double x;             /* x coordinate of the particle position */
  double y;             /* y coordinate of the particle position */
  double z;             /* z coordinate of the particle position */
  double size;          /* radius of the cell */
  double h;             /* neighbourhood of the cell */
  double v;             /* particle potential */
  double density;       /* particle density */
  double scalarField;   /* additional scalar field which can be used for analysis of results (printed to the output VTK files) */
  int ctype;            /* cell type 1=endothelial */
  int scstage;          /* stem cells stage (in the course of differentiation) */
  unsigned char tumor;  /* 1 - tumor cell, 0 - healthly cell */
} cell_data;

double MIC_ATTR csize;

double MIC_ATTR h;               /* cell neighbourhood radius */
double MIC_ATTR h2;              /* 2nd power of h */
double MIC_ATTR h3;              /* 3rd power of h */
double MIC_ATTR h4;              /* 4th power of h */
